[gimp] Fix various typos
- From: Michael Natterer <mitch src gnome org>
- To: commits-list gnome org
- Cc:
- Subject: [gimp] Fix various typos
- Date: Sat, 21 Sep 2019 17:11:03 +0000 (UTC)
commit 44d10e458cf0a0acc37ce1b771e6e8ea06dfddb7
Author: luzpaz <kunda scribus net>
Date: Sat Sep 21 17:10:46 2019 +0000
Fix various typos
Found via `codespell` (v1.17.0.dev0)
app/core/gimpbrush-load.c | 2 +-
app/core/gimpdrawable-floating-selection.c | 2 +-
app/core/gimpdrawable-gradient.c | 2 +-
app/core/gimpextension.c | 2 +-
app/core/gimpimage-convert-indexed.c | 16 ++++++++--------
app/display/gimptoolrectangle.c | 2 +-
app/gui/session.c | 2 +-
app/meson.build | 2 +-
app/widgets/gimptoolbox-dnd.c | 2 +-
devel-docs/libgimp/libgimp3-docs.sgml | 2 +-
docs/Wilber.xcf.gz.README | 2 +-
libgimp/gimpfileprocedure.c | 2 +-
libgimp/gimpitem.c | 2 +-
libgimp/gimpplugin.c | 4 ++--
libgimp/gimpplugin.h | 2 +-
libgimp/gimpprocedureconfig.c | 2 +-
libgimpbase/gimpbasetypes.c | 4 ++--
meson.build | 8 ++++----
plug-ins/common/blinds.c | 6 +++---
plug-ins/common/file-compressor.c | 2 +-
plug-ins/common/file-pdf-save.c | 4 ++--
plug-ins/common/film.c | 2 +-
plug-ins/common/mail.c | 2 +-
plug-ins/common/nl-filter.c | 4 ++--
plug-ins/common/sample-colorize.c | 4 ++--
plug-ins/common/tile-small.c | 2 +-
plug-ins/file-dds/README.dxt | 2 +-
plug-ins/file-fli/fli-gimp.c | 6 +++---
plug-ins/goat-exercises/goat-exercise-c.c | 2 +-
plug-ins/pygimp/doc/pygimp.sgml | 2 +-
plug-ins/script-fu/scripts/palette-export.scm | 4 ++--
tools/gimp-test-clipboard.c | 2 +-
32 files changed, 52 insertions(+), 52 deletions(-)
---
diff --git a/app/core/gimpbrush-load.c b/app/core/gimpbrush-load.c
index 63a453ebc9..8330ca1901 100644
--- a/app/core/gimpbrush-load.c
+++ b/app/core/gimpbrush-load.c
@@ -647,7 +647,7 @@ gimp_brush_load_abr_brush_v12 (GDataInputStream *input,
case 1: /* computed brush */
/* FIXME: support it!
*
- * We can probabaly feed the info into the generated brush code
+ * We can probably feed the info into the generated brush code
* and get a usable brush back. It seems to support the same
* types -akl
*/
diff --git a/app/core/gimpdrawable-floating-selection.c b/app/core/gimpdrawable-floating-selection.c
index ad5c387de9..62afd771ee 100644
--- a/app/core/gimpdrawable-floating-selection.c
+++ b/app/core/gimpdrawable-floating-selection.c
@@ -166,7 +166,7 @@ gimp_drawable_get_floating_sel_filter (GimpDrawable *drawable)
g_return_val_if_fail (GIMP_IS_DRAWABLE (drawable), NULL);
g_return_val_if_fail (gimp_drawable_get_floating_sel (drawable) != NULL, NULL);
- /* Ensure that the graph is construced before the filter is used.
+ /* Ensure that the graph is constructed before the filter is used.
* Otherwise, we rely on the projection to cause the graph to be
* constructed, which fails for images that aren't displayed.
*/
diff --git a/app/core/gimpdrawable-gradient.c b/app/core/gimpdrawable-gradient.c
index 2d7cbe8b86..8e7e6ec272 100644
--- a/app/core/gimpdrawable-gradient.c
+++ b/app/core/gimpdrawable-gradient.c
@@ -198,7 +198,7 @@ gimp_drawable_gradient_shapeburst_distmap (GimpDrawable *drawable,
component_format = babl_format ("A float");
- /* extract the aplha into the temp mask */
+ /* extract the alpha into the temp mask */
gegl_buffer_set_format (temp_buffer, component_format);
gimp_gegl_buffer_copy (gimp_drawable_get_buffer (drawable), region,
GEGL_ABYSS_NONE,
diff --git a/app/core/gimpextension.c b/app/core/gimpextension.c
index 1e958644d0..68b19542f1 100644
--- a/app/core/gimpextension.c
+++ b/app/core/gimpextension.c
@@ -440,7 +440,7 @@ gimp_extension_load (GimpExtension *extension,
if (error && *error == NULL)
*error = g_error_new (GIMP_EXTENSION_ERROR,
GIMP_EXTENSION_NO_VERSION,
- _("Extension AppData must advertize a version in a <release> tag."));
+ _("Extension AppData must advertise a version in a <release> tag."));
success = FALSE;
}
diff --git a/app/display/gimptoolrectangle.c b/app/display/gimptoolrectangle.c
index c0c3a3ef7e..14fe231993 100644
--- a/app/display/gimptoolrectangle.c
+++ b/app/display/gimptoolrectangle.c
@@ -172,7 +172,7 @@ struct _GimpToolRectanglePrivate
gdouble x1, y1;
gdouble x2, y2;
- /* Integer coordinats of upper left corner and size. We must
+ /* Integer coordinates of upper left corner and size. We must
* calculate this separately from the gdouble ones because sometimes
* we don't want to affect the integer size (e.g. when moving the
* rectangle), but that will be the case if we always calculate the
diff --git a/app/gui/session.c b/app/gui/session.c
index 3d52817dd4..79caa11dac 100644
--- a/app/gui/session.c
+++ b/app/gui/session.c
@@ -216,7 +216,7 @@ session_init (Gimp *gimp)
{
g_object_unref (info);
- /* set token to left paren to we won't set another
+ /* set token to left paren so we won't set another
* error below, gimp_config_deserialize() already did
*/
token = G_TOKEN_LEFT_PAREN;
diff --git a/app/meson.build b/app/meson.build
index 0bf21255d6..8e56a0c6ba 100644
--- a/app/meson.build
+++ b/app/meson.build
@@ -65,7 +65,7 @@ libapp = static_library('app',
)
-# Those subdirs need to link againts the first ones
+# Those subdirs need to link against the first ones
subdir('config')
# subdir('tests')
diff --git a/app/widgets/gimptoolbox-dnd.c b/app/widgets/gimptoolbox-dnd.c
index f0002415ef..4a178886e9 100644
--- a/app/widgets/gimptoolbox-dnd.c
+++ b/app/widgets/gimptoolbox-dnd.c
@@ -95,7 +95,7 @@ gimp_toolbox_dnd_init (GimpToolbox *toolbox,
context = gimp_toolbox_get_context (toolbox);
- /* Before caling any dnd helper functions, setup the drag
+ /* Before calling any dnd helper functions, setup the drag
* destination manually since we want to handle all drag events
* manually, otherwise we would not be able to give the drag handler
* a chance to handle drag events
diff --git a/devel-docs/libgimp/libgimp3-docs.sgml b/devel-docs/libgimp/libgimp3-docs.sgml
index 8322c08f37..dc74bbe220 100644
--- a/devel-docs/libgimp/libgimp3-docs.sgml
+++ b/devel-docs/libgimp/libgimp3-docs.sgml
@@ -46,7 +46,7 @@
</chapter>
<chapter id="libgimp-image">
- <title>Manupulating Images and their Properties</title>
+ <title>Manipulating Images and their Properties</title>
<xi:include href="xml/gimpchannel.xml" />
<xi:include href="xml/gimpdisplay.xml" />
<xi:include href="xml/gimpdrawable.xml" />
diff --git a/docs/Wilber.xcf.gz.README b/docs/Wilber.xcf.gz.README
index deff6698fc..4c684aea82 100644
--- a/docs/Wilber.xcf.gz.README
+++ b/docs/Wilber.xcf.gz.README
@@ -4,7 +4,7 @@ Wilber.xcf.gz.README
This is Wilber, the Gimp Mascot.
Gimp is a image manipulation program for unix computers, see
-https://www.gimp.org for more detais.
+https://www.gimp.org for more details.
The use of Wilber.xcf.gz is free, though it would be kind of you to mention
the original author (Tuomas Kuosmanen <tigert gimp org>) somewhere.
diff --git a/libgimp/gimpfileprocedure.c b/libgimp/gimpfileprocedure.c
index c6e0e0709d..b27656ceeb 100644
--- a/libgimp/gimpfileprocedure.c
+++ b/libgimp/gimpfileprocedure.c
@@ -211,7 +211,7 @@ gimp_file_procedure_get_prefixes (GimpFileProcedure *procedure)
* gimp_file_procedure_set_magics:
* @procedure: A #GimpFileProcedure.
* @magics: A comma separated list of magic file information this procedure
- * can hande (i.e. "0,string,GIF").
+ * can handle (i.e. "0,string,GIF").
*
* Since: 3.0
**/
diff --git a/libgimp/gimpitem.c b/libgimp/gimpitem.c
index 45b89adcc4..6a476b2d58 100644
--- a/libgimp/gimpitem.c
+++ b/libgimp/gimpitem.c
@@ -330,7 +330,7 @@ gimp_item_is_vectors (GimpItem *item)
*
* Returns: (element-type GimpItem) (transfer container):
* The item's list of children.
- * The returned ist must be freed with g_list_free(). Item
+ * The returned list must be freed with g_list_free(). Item
* elements belong to libgimp and must not be unrefed.
*
* Since: 3.0
diff --git a/libgimp/gimpplugin.c b/libgimp/gimpplugin.c
index d1cca6595b..d85c626d10 100644
--- a/libgimp/gimpplugin.c
+++ b/libgimp/gimpplugin.c
@@ -88,7 +88,7 @@
* #GimpProcedure using #GimpProcedureClass.register().
*
* The plug-in is called in "run" mode whenever one of the procedures
- * it implements is called by either the main GIMP appliction or any
+ * it implements is called by either the main GIMP application or any
* other plug-in. In "run" mode, one of the procedure names returned
* by #GimpPlugInClass.query_procedures() or
* #GimpPlugInClass.init_procedures() is passed to
@@ -98,7 +98,7 @@
*
* In any of the three modes, #GimpPlugInClass.quit() is called before
* the plug-in process exits, so the plug-in can perform whatever
- * cleanup neccessary.
+ * cleanup necessary.
*
* Since: 3.0
**/
diff --git a/libgimp/gimpplugin.h b/libgimp/gimpplugin.h
index b81e05940d..879fd17fcc 100644
--- a/libgimp/gimpplugin.h
+++ b/libgimp/gimpplugin.h
@@ -82,7 +82,7 @@ struct _GimpPlugIn
* @quit: This method can be overridden by a plug-in which needs to
* perform some actions upon quitting.
*
- * A class which every plug-in should sublass, while overriding
+ * A class which every plug-in should subclass, while overriding
* #GimpPlugInClass.query_procedures() and/or
* #GimpPlugInClass.init_procedures(), as well as
* #GimpPlugInClass.create_procedure().
diff --git a/libgimp/gimpprocedureconfig.c b/libgimp/gimpprocedureconfig.c
index cec4646e06..7ff3e7be98 100644
--- a/libgimp/gimpprocedureconfig.c
+++ b/libgimp/gimpprocedureconfig.c
@@ -32,7 +32,7 @@
* #GimpProcedureConfig base class for #GimpProcedure-specific config
* objects and the main interface to manage aspects of
* #GimpProcedure's arguments such as persistency of the last used
- * argments across GIMP sessions.
+ * arguments across GIMP sessions.
*
* A #GimpProcedureConfig is created by a #GimpProcedure using
* gimp_procedure_create_config() and its properties match the
diff --git a/libgimpbase/gimpbasetypes.c b/libgimpbase/gimpbasetypes.c
index fafb087f3e..7145d6086b 100644
--- a/libgimpbase/gimpbasetypes.c
+++ b/libgimpbase/gimpbasetypes.c
@@ -149,7 +149,7 @@ gimp_enum_set_value_descriptions (GType enum_type,
* gimp_enum_get_value_descriptions:
* @enum_type: a #GType
*
- * Retreives the array of human readable and translatable descriptions
+ * Retrieves the array of human readable and translatable descriptions
* and help texts for enum values.
*
* Returns: a %NULL terminated constant array of #GimpEnumDesc
@@ -191,7 +191,7 @@ gimp_flags_set_value_descriptions (GType flags_type,
* gimp_flags_get_value_descriptions:
* @flags_type: a #GType
*
- * Retreives the array of human readable and translatable descriptions
+ * Retrieves the array of human readable and translatable descriptions
* and help texts for flags values.
*
* Returns: a %NULL terminated constant array of #GimpFlagsDesc
diff --git a/meson.build b/meson.build
index 839a99840c..1cb0203307 100644
--- a/meson.build
+++ b/meson.build
@@ -70,7 +70,7 @@ versionconfig.set('GIMP_VERSION', gimp_version)
versionconfig.set('GIMP_API_VERSION', gimp_api_version)
-# Libtool versionning
+# Libtool versioning
gimp_interface_age = 0
lt_current = 0
lt_revision = gimp_app_version_micro
@@ -1125,7 +1125,7 @@ conf.set('HAVE_GETTEXT', true)
################################################################################
-# Miscelaneous configuration
+# Miscellaneous configuration
# #
## ## # #### ####
@@ -1420,7 +1420,7 @@ add_project_arguments(compiler_args, language: [ 'c', 'cpp' ])
add_project_link_arguments(linker_args, language: [ 'c', 'cpp' ])
################################################################################
-# Miscelaneous targets
+# Miscellaneous targets
# # #######
@@ -1681,7 +1681,7 @@ final_message = [
message('\n'.join(final_message))
if warnings.length() > 0
- warning('Warnings occured during configuration')
+ warning('Warnings occurred during configuration')
foreach warning : warnings
warning(warning)
endforeach
diff --git a/plug-ins/common/blinds.c b/plug-ins/common/blinds.c
index 210fb174ce..ff7981dff2 100644
--- a/plug-ins/common/blinds.c
+++ b/plug-ins/common/blinds.c
@@ -21,7 +21,7 @@
* You should have received a copy of the GNU General Public License
* along with this program. If not, see <https://www.gnu.org/licenses/>.
*
- * A fair proprotion of this code was taken from the Whirl plug-in
+ * A fair proportion of this code was taken from the Whirl plug-in
* which was copyrighted by Federico Mena Quintero (as below).
*
* Whirl plug-in --- distort an image into a whirlpool
@@ -540,7 +540,7 @@ dialog_update_preview (GimpDrawable *drawable,
{
/* Horizontal blinds */
/* Apply the blinds algo to a single column -
- * this act as a transfomation matrix for the
+ * this act as a transformation matrix for the
* rows. Make row 0 invalid so we can find it again!
*/
gint i;
@@ -683,7 +683,7 @@ apply_blinds (GimpDrawable *drawable)
{
/* Horizontal blinds */
/* Apply the blinds algo to a single column -
- * this act as a transfomation matrix for the
+ * this act as a transformation matrix for the
* rows. Make row 0 invalid so we can find it again!
*/
gint i;
diff --git a/plug-ins/common/file-compressor.c b/plug-ins/common/file-compressor.c
index becd7a4a4a..fc8305d8a6 100644
--- a/plug-ins/common/file-compressor.c
+++ b/plug-ins/common/file-compressor.c
@@ -21,7 +21,7 @@
/* compressor plug-in for GIMP */
/* based on gz.c which in turn is */
-/* loosley based on url.c by */
+/* loosely based on url.c by */
/* Josh MacDonald, jmacd cs berkeley edu */
/* and, very loosely on hrz.c by */
diff --git a/plug-ins/common/file-pdf-save.c b/plug-ins/common/file-pdf-save.c
index 352ae319ec..276d4dad86 100644
--- a/plug-ins/common/file-pdf-save.c
+++ b/plug-ins/common/file-pdf-save.c
@@ -44,7 +44,7 @@
* 1. Grayscale layers are inverted (although layer masks which are not grayscale,
* are not inverted)
* 2. Exporting some fonts doesn't work since gimp_text_layer_get_font Returns a
- * font which is sometimes incompatiable with pango_font_description_from_string
+ * font which is sometimes incompatible with pango_font_description_from_string
* (gimp_text_layer_get_font sometimes returns suffixes such as "semi-expanded" to
* the font's name although the GIMP's font selection dialog shows the don'ts name
* normally - This should be checked again in GIMP 2.7)
@@ -88,7 +88,7 @@
* Fixed a typo that prevented the plugin from compiling...
* A migration to the new GIMP 2.8 api, which includes:
* - Now using gimp_export_dialog_new
- * - Using gimp_text_layer_get_hint_style (2.8) instead of the depreceated
+ * - Using gimp_text_layer_get_hint_style (2.8) instead of the deprecated
* gimp_text_layer_get_hinting (2.6).
*
* August 24, 2010 | Barak Itkin <lightningismyname gmail com>
diff --git a/plug-ins/common/film.c b/plug-ins/common/film.c
index 1e76485988..d14f26263a 100644
--- a/plug-ins/common/film.c
+++ b/plug-ins/common/film.c
@@ -292,7 +292,7 @@ film_create_procedure (GimpPlugIn *plug_in,
GIMP_PROC_VAL_IMAGE (procedure, "new-image",
"New image",
- "Outout image",
+ "Output image",
FALSE,
G_PARAM_READWRITE);
}
diff --git a/plug-ins/common/mail.c b/plug-ins/common/mail.c
index c8cb8a6539..9adacbbf1f 100644
--- a/plug-ins/common/mail.c
+++ b/plug-ins/common/mail.c
@@ -797,7 +797,7 @@ sendmail_create_headers (FILE *mailpipe)
/* create all the mail header stuff. Feel free to add your own */
/* It is advisable to leave the X-Mailer header though, as */
/* there is a possibility of a Gimp mail scanner/reader in the */
- /* future. It will probabaly need that header. */
+ /* future. It will probably need that header. */
fprintf (mailpipe, "To: %s \n", mail_info.receipt);
fprintf (mailpipe, "Subject: %s \n", mail_info.subject);
diff --git a/plug-ins/common/nl-filter.c b/plug-ins/common/nl-filter.c
index 8735952abf..3eef5d4cc7 100644
--- a/plug-ins/common/nl-filter.c
+++ b/plug-ins/common/nl-filter.c
@@ -821,12 +821,12 @@ hex_area (gdouble sx, gdouble sy, gdouble hx, gdouble hy, gdouble d)
gdouble hx0,hx1,hx2,hy0,hy1,hy2,hy3;
gdouble sx0,sx1,sy0,sy1;
- /* compute square co-ordinates */
+ /* compute square coordinates */
sx0 = sx - 0.5;
sy0 = sy - 0.5;
sx1 = sx + 0.5;
sy1 = sy + 0.5;
- /* compute hexagon co-ordinates */
+ /* compute hexagon coordinates */
hx0 = hx - d/2.0;
hx1 = hx;
hx2 = hx + d/2.0;
diff --git a/plug-ins/common/sample-colorize.c b/plug-ins/common/sample-colorize.c
index e1bb477b6b..9ce3643095 100644
--- a/plug-ins/common/sample-colorize.c
+++ b/plug-ins/common/sample-colorize.c
@@ -309,7 +309,7 @@ colorize_create_procedure (GimpPlugIn *plug_in,
" in the sample colortable. If hold_inten is FALSE the picked color"
" is used 1:1 as resulting remap_color."
" If hold_inten is TRUE The brightness of the picked color is adjusted"
- " back to the origial intensity value (only hue and saturation are"
+ " back to the original intensity value (only hue and saturation are"
" taken from the picked sample color)"
" (or to the input level, if orig_inten is set FALSE)"
" Works on both Grayscale and RGB image with/without alpha channel."
@@ -1042,7 +1042,7 @@ levels_update (gint update)
gint i;
if (g_Sdebug)
- g_printf ("levels_update: update reques %x\n", update);
+ g_printf ("levels_update: update request %x\n", update);
/* Recalculate the transfer array */
calculate_level_transfers ();
diff --git a/plug-ins/common/tile-small.c b/plug-ins/common/tile-small.c
index e5c6982c89..91d09aaa3d 100644
--- a/plug-ins/common/tile-small.c
+++ b/plug-ins/common/tile-small.c
@@ -20,7 +20,7 @@
* You should have received a copy of the GNU General Public License
* along with this program. If not, see <https://www.gnu.org/licenses/>.
*
- * A fair proprotion of this code was taken from the Whirl plug-in
+ * A fair proportion of this code was taken from the Whirl plug-in
* which was copyrighted by Federico Mena Quintero (as below).
*
* Whirl plug-in --- distort an image into a whirlpool
diff --git a/plug-ins/file-dds/README.dxt b/plug-ins/file-dds/README.dxt
index 5cdbb97307..46731842e2 100644
--- a/plug-ins/file-dds/README.dxt
+++ b/plug-ins/file-dds/README.dxt
@@ -14,7 +14,7 @@ Pixels".
lerp_rgb: The expression computed is exactly equivalent to mul8bit(a[i],255-f)
+ mul8bit(b[i],f) - I just verified that by brute force for -255 <= b[i]-a[i]
<= 255 because I couldn't be bothered to find a derivation for this :) . You
-customarily use a factor between 0 and 256 incluse for LERPing if you can, but
+customarily use a factor between 0 and 256 include for LERPing if you can, but
normal DXT blocks have colors placed at 1/3 and 2/3 between the two
interpolated colors. 255 is divisible by 3, so lerp_rgb can later be used in
eval_colors to determine the result of
diff --git a/plug-ins/file-fli/fli-gimp.c b/plug-ins/file-fli/fli-gimp.c
index f668c15deb..de70aae40f 100644
--- a/plug-ins/file-fli/fli-gimp.c
+++ b/plug-ins/file-fli/fli-gimp.c
@@ -181,7 +181,7 @@ fli_create_procedure (GimpPlugIn *plug_in,
gimp_procedure_set_documentation (procedure,
"Load FLI-movies",
- "This is an experimantal plug-in to "
+ "This is an experimental plug-in to "
"handle FLI movies",
name);
gimp_procedure_set_attribution (procedure,
@@ -218,7 +218,7 @@ fli_create_procedure (GimpPlugIn *plug_in,
gimp_procedure_set_documentation (procedure,
"Export FLI-movies",
- "This is an experimantal plug-in to "
+ "This is an experimental plug-in to "
"handle FLI movies",
name);
gimp_procedure_set_attribution (procedure,
@@ -251,7 +251,7 @@ fli_create_procedure (GimpPlugIn *plug_in,
gimp_procedure_set_documentation (procedure,
"Get information about a Fli movie",
- "This is an experimantal plug-in to "
+ "This is an experimental plug-in to "
"handle FLI movies",
name);
gimp_procedure_set_attribution (procedure,
diff --git a/plug-ins/goat-exercises/goat-exercise-c.c b/plug-ins/goat-exercises/goat-exercise-c.c
index 6c76419408..d4586c2725 100644
--- a/plug-ins/goat-exercises/goat-exercise-c.c
+++ b/plug-ins/goat-exercises/goat-exercise-c.c
@@ -139,7 +139,7 @@ goat_run (GimpProcedure *procedure,
INIT_I18N();
- /* In interactive mode, display a dialog to advertize the exercise. */
+ /* In interactive mode, display a dialog to advertise the exercise. */
if (run_mode == GIMP_RUN_INTERACTIVE)
{
GtkTextBuffer *buffer;
diff --git a/plug-ins/pygimp/doc/pygimp.sgml b/plug-ins/pygimp/doc/pygimp.sgml
index 41b6a579fc..6277559770 100644
--- a/plug-ins/pygimp/doc/pygimp.sgml
+++ b/plug-ins/pygimp/doc/pygimp.sgml
@@ -2134,7 +2134,7 @@ main()
<ListItem>
<Para>The registered procedure name (first parameter of the
<Literal>register()</Literal> function) is mangled: all underscores
- are converted to hyphens, to better match the usual Scheme syntatic
+ are converted to hyphens, to better match the usual Scheme syntactic
style (here, <Literal>console_echo</Literal> becomes
<Literal>console-echo</Literal>). Moreover, a
<Literal>python-fu-</Literal> prefix is automatically added; it is
diff --git a/plug-ins/script-fu/scripts/palette-export.scm b/plug-ins/script-fu/scripts/palette-export.scm
index ecb16df7fe..0286c4bad7 100644
--- a/plug-ins/script-fu/scripts/palette-export.scm
+++ b/plug-ins/script-fu/scripts/palette-export.scm
@@ -95,7 +95,7 @@
; Convert a color to a simple pair of braces with comma separated values
; '(255 255 255) => "(255, 255, 255)"
-(define (color-rgb-to-comma-seperated-list color)
+(define (color-rgb-to-comma-separated-list color)
(string-append "(" (number->string (color-get-red color))
", " (number->string (color-get-green color))
", " (number->string (color-get-blue color)) ")")
@@ -377,7 +377,7 @@
" public "
(name-standard palette-name) "() {"))
(export-palette (car (gimp-context-get-palette))
- color-rgb-to-comma-seperated-list
+ color-rgb-to-comma-separated-list
name-no-conversion
" colors = new Hashtable<String,Color>();\n" ; start
" colors.put(\"" ; name-pre
diff --git a/tools/gimp-test-clipboard.c b/tools/gimp-test-clipboard.c
index 04f02e3413..7ebf3565a2 100644
--- a/tools/gimp-test-clipboard.c
+++ b/tools/gimp-test-clipboard.c
@@ -96,7 +96,7 @@ static const GOptionEntry main_entries[] =
{
"paste", 'p', 0,
G_OPTION_ARG_STRING, &option_paste_filename,
- "Paste clipoard into <file> ('-' pastes to STDOUT)", "<file>"
+ "Paste clipboard into <file> ('-' pastes to STDOUT)", "<file>"
},
{
"version", 'v', G_OPTION_FLAG_NO_ARG,
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/app/core/gimpimage-convert-indexed.c b/app/core/gimpimage-convert-indexed.c
index 7897b79719..47c6fa1259 100644
--- a/app/core/gimpimage-convert-indexed.c
+++ b/app/core/gimpimage-convert-indexed.c
@@ -119,13 +119,13 @@
/* CODE READABILITY BUGS:
*
* . Most uses of variants of the R,G,B variable naming convention
* are referring to L*a*b* co-ordinates, not RGB co-ordinates!
*
* . Each said variable is usually one of the following, but it is
* rarely clear which one:
* - (assumed sRGB) raw non-linear 8-bit RGB co-ordinates
* - 'full'-precision (unshifted) 8-bit L*a*b* co-ordinates
* - box-space (reduced-precision shifted L*a*b*) co-ordinates
*/
#include "config.h"
@@ -214,9 +214,9 @@ typedef double etype;
/*
We provide two different histogram access interfaces. HIST_LIN()
accesses the histogram in histogram-native space, taking absolute
- histogram co-ordinates. HIST_RGB() accesses the histogram in RGB
- space. This latter takes unsigned 8-bit co-ordinates, internally
- converts those co-ordinates to histogram-native space and returns
+ histogram coordinates. HIST_RGB() accesses the histogram in RGB
+ space. This latter takes unsigned 8-bit coordinates, internally
+ converts those coordinates to histogram-native space and returns
the access pointer to the corresponding histogram cell.
Using these two interfaces we can import RGB data into a more
@@ -3555,7 +3555,7 @@ median_cut_pass2_nodestruct_dither_rgb (QuantizeObj *quantobj,
goto got_color;
}
}
- g_error ("Non-existant color was expected to "
+ g_error ("Non-existent color was expected to "
"be in non-destructive colormap.");
got_color:
dest[INDEXED] = lastindex;
@@ -119,13 +119,13 @@
*
* . Most uses of variants of the R,G,B variable naming convention
- * are referring to L*a*b* co-ordinates, not RGB co-ordinates!
+ * are referring to L*a*b* coordinates, not RGB coordinates!
*
* . Each said variable is usually one of the following, but it is
@@ -119,13 +119,13 @@
* . Each said variable is usually one of the following, but it is
* rarely clear which one:
- * - (assumed sRGB) raw non-linear 8-bit RGB co-ordinates
- * - 'full'-precision (unshifted) 8-bit L*a*b* co-ordinates
- * - box-space (reduced-precision shifted L*a*b*) co-ordinates
+ * - (assumed sRGB) raw non-linear 8-bit RGB coordinates
+ * - 'full'-precision (unshifted) 8-bit L*a*b* coordinates
+ * - box-space (reduced-precision shifted L*a*b*) coordinates
*/
#include "config.h"